@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13_01';
+our $VERSION = '0.13_02';
 $VERSION =~ tr/_//d;
 
 use Carp qw(verbose); # makes carp() cluck and croak() confess
@@ -114,33 +114,18 @@ but will stay there as a redirection to this module).
 
 =head1 SEE ALSO
 
-=over 4
-
-=item *
-
 L<Carp>
 
-=item *
-
 L<Acme::JavaTrace> and L<Devel::SimpleTrace>
 
-=item *
-
 L<Carp::Always::Color>
 
-=item *
-
 L<Carp::Source::Always>
 
-=back
-
-Please report bugs via CPAN RT 
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Carp-Always.
+L<Devel::Confess>
 
 =head1 BUGS
 
-Every (un)deserving module has its own pet bugs.
-
 =over 4
 
 =item *
@@ -153,13 +138,13 @@ C<$SIG{'__DIE__'}>.
 
 Test scripts are good. I should write more of these.
 
-=item *
-
-I don't know if this module name is still a bug as it was
-at the time of C<Carp::Indeed>.
-
 =back
 
+Please report bugs via GitHub
+https://github.com/aferreira/cpan-Carp-Always/issues
+
+Backlog in CPAN RT: https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Always
+
 =head1 AUTHOR
 
 Adriano Ferreira, E<lt>ferreira@cpan.orgE<gt>
